summaryrefslogtreecommitdiff
path: root/config.def.h
diff options
context:
space:
mode:
Diffstat (limited to 'config.def.h')
-rw-r--r--config.def.h36
1 files changed, 23 insertions, 13 deletions
diff --git a/config.def.h b/config.def.h
index 6eb96ce..010394a 100644
--- a/config.def.h
+++ b/config.def.h
@@ -13,6 +13,10 @@ static const float focuscolor[] = COLOR(0x005577ff);
static const float urgentcolor[] = COLOR(0xff0000ff);
/* This conforms to the xdg-protocol. Set the alpha to zero to restore the old behavior */
static const float fullscreen_bg[] = {0.0f, 0.0f, 0.0f, 1.0f}; /* You can also use glsl colors */
+static const float default_opacity_unfocus = 0.70f;
+static const float default_opacity_focus = 1.00f;
+static const float dof = default_opacity_focus;
+static const float dou = default_opacity_unfocus;
/* tagging - TAGCOUNT must be no greater than 31 */
#define TAGCOUNT (5)
@@ -22,19 +26,20 @@ static int log_level = WLR_ERROR;
static const Rule rules[] = {
/* app_id title tags mask isfloating monitor */
-// { "Gimp_EXAMPLE", NULL, 0, 1, -1 },
-// /* Start on currently visible tags floating, not tiled */
-// { "firefox_EXAMPLE", NULL, 1 << 8, 0, -1 },
-// /* Start on ONLY tag "9" */
- { "Gimp", NULL, 0, 1, -1 },
- { "mpv", NULL, 0, 1, -1 },
- { "Firefox", NULL, 1, 0, -1 },
- { "firefox", NULL, 1, 0, -1 },
- { "LibreWolf", NULL, 1, 0, -1 },
- { "librewolf", NULL, 1, 0, -1 },
- { "Thunderbird", NULL, 1 << 1, 0, 0 },
- { "Pavucontrol", NULL, 1 << 4, 0, 0 },
- { "pavucontrol", NULL, 1 << 4, 0, 0 },
+// { "Gimp_EXAMPLE", NULL, 0, 1, -1 }, /* Start on currently visible tags floating, not tiled */
+// { "firefox_EXAMPLE", NULL, 1 << 8, 0, -1 }, /* Start on ONLY tag "9" */
+// { "Gimp_EXAMPLE", NULL, 0, 1, 1.00, 0.20, -1 }, /* Start on currently visible tags floating, not tiled */
+// { "firefox_EXAMPLE", NULL, 1 << 8, 0, 1.00, 1.00, -1 }, /* Start on ONLY tag "9" */
+ /* app_id title tags mask isfloating alpha focus alpha unfocus monitor */
+ { "Gimp", NULL, 0, 1, dof dou -1 },
+ { "mpv", NULL, 0, 1, dof dou -1 },
+ { "Firefox", NULL, 1, 0, dof dou -1 },
+ { "firefox", NULL, 1, 0, dof dou -1 },
+ { "LibreWolf", NULL, 1, 0, dof dou -1 },
+ { "librewolf", NULL, 1, 0, dof dou -1 },
+ { "Thunderbird",NULL, 1 << 1, 0, dof dou 0 },
+ { "Pavucontrol",NULL, 1 << 4, 0, dof dou 0 },
+ { "pavucontrol",NULL, 1 << 4, 0, dof dou 0 },
/* default/example rule: can be changed but cannot be eliminated; at least one rule must exist */
};
@@ -164,6 +169,11 @@ static const Key keys[] = {
{ MODKEY, XKB_KEY_t, setlayout, {.v = &layouts[0]} },
{ MODKEY, XKB_KEY_f, setlayout, {.v = &layouts[1]} },
{ MODKEY, XKB_KEY_m, setlayout, {.v = &layouts[2]} },
+ // From client-opacity-focus patch
+ { MODKEY|WLR_MODIFIER_CTRL, XKB_KEY_k, setopacityunfocus, {.f = +0.1f} },
+ { MODKEY|WLR_MODIFIER_CTRL, XKB_KEY_j, setopacityunfocus, {.f = -0.1f} },
+ { MODKEY|WLR_MODIFIER_CTRL|WLR_MODIFIER_SHIFT, XKB_KEY_K, setopacityfocus, {.f = +0.1f} },
+ { MODKEY|WLR_MODIFIER_CTRL|WLR_MODIFIER_SHIFT, XKB_KEY_J, setopacityfocus, {.f = -0.1f} },
{ MODKEY, XKB_KEY_space, setlayout, {0} },
{ MODKEY|WLR_MODIFIER_SHIFT, XKB_KEY_space, togglefloating, {0} },
{ MODKEY, XKB_KEY_e, togglefullscreen, {0} },